#!/bin/ksh
# ******************************************************************************************************************************
# * Licensed Materials - Property of IBM                                                                                       *
# * (c) Copyright IBM Corp. 2008, 2009 All Rights Reserved.                                                                    *
# *                                                                                                                            *
# *US Government Users Restricted Rights - Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp*
# ******************************************************************************************************************************

rcrdone(){
db2 connect reset
db2 terminate
echo $MESSAGE:$EXITCODE
echo $CRREWECH002$
exit $EXITCODE
}

validate() {

if [ -z $CURINST ] 
then
	EXITCODE=$CRREW4501E
	MESSAGE=$CRREWMSGE001
	rcrdone
fi  

if [ -z $DBNAME ] 
then
	EXITCODE=$CRREW4502E
	MESSAGE=$CRREWMSGE002
	rcrdone
fi

if [ -z $DBUSER ] 
then
	EXITCODE=$CRREW4503E
	MESSAGE=$CRREWMSGE003
	rcrdone
fi

if [ -z $DBPASSWD ] 
then
	EXITCODE=$CRREW4504E
	MESSAGE=$CRREWMSGE004
	rcrdone
fi

if [ -z $NF_SCHEMA ] 
then
	EXITCODE=$CRREW4505E
	MESSAGE=$CRREWMSGE005
	rcrdone
fi

if [ -z $STAR_SCHEMA ] 
then
	EXITCODE=$CRREW4506E
	MESSAGE=$CRREWMSGE006
	rcrdone
fi

if [ -z $REP_USER ] 
then
	EXITCODE=$CRREW4507E
	MESSAGE=$CRREWMSGE007
	rcrdone
fi

if [ $DBUSER == $REP_USER ]
then
	EXITCODE=$CRREW4595E
	MESSAGE=$CRREWMSGE095
	rcrdone
fi


if [ -z $DATA_HOME ] 
then
	EXITCODE=$CRREW4508E
	MESSAGE=$CRREWMSGE008
	rcrdone
fi

if [ -z $LANG ]
then
	EXITCODE=$CRREW4585E
	MESSAGE=$CRREWMSGE085
	rcrdone
fi

db2ilist>db2ilist.txt
grep -e $CURINST db2ilist.txt>/dev/null
if [ $? -eq 1 ]
then
	rm -f db2ilist.txt
	EXITCODE=$CRREW4501E
	MESSAGE=$CRREWMSGE001
	rcrdone
fi  

rm -f db2ilist.txt

db2 attach to  $CURINST user $DBUSER using  "$DBPASSWD"
if [ $? -ne 0 ] 
then
	EXITCODE=$CRREW4584E
	MESSAGE=$CRREWMSGE084
	rcrdone
fi  



rcrdone
}

chmod -R +x lang

if [ `echo $LANG | sed 's/\([a-z]*\).*/\1/'` == "en" ]
then 
     LOCALE="en"
	. lang/en/messages.sh
fi	

if [ `echo $LANG | sed 's/\([a-z]*\).*/\1/'` == "it" ]
then 
	LOCALE="it"
	. lang/it/messages.sh
fi	

if [ `echo $LANG | sed 's/\([a-z]*\).*/\1/'` == "pl" ]
then 
	LOCALE="pl"
	. lang/pl/messages.sh
fi	

if [ `echo $LANG | sed 's/\([a-z]*\).*/\1/'` == "ko" ]
then 
	LOCALE="kr"
	. lang/kr/messages.sh
fi

if [ `echo $LANG | sed 's/\([a-z]*\).*/\1/'` == "ja" ]
then 
	LOCALE="ja"
	. lang/ja/messages.sh
fi

if [ `echo $LANG | sed 's/\([a-z]*_[A-Z][A-Z]\).*/\1/'` == "zh_CN" ]
then 
	LOCALE="zh_CN"
	. lang/zh_CN/messages.sh
fi

if [ `echo $LANG | sed 's/\([a-z]*_[A-Z][A-Z]\).*/\1/'` == "zh_TW" ]
then 
	LOCALE="zh_TW"
	. lang/zh_TW/messages.sh
fi

if [ -z $LOCALE ]
then
	 LOCALE="en"
	. lang/en/messages.sh
fi	


SILENT=0
MESSAGE="No errors"
EXITCODE=0

DB2_CMD="db2 -tsf"

if [ $# -eq 1 ]
	then 
	if [ $1 == "-silent" ]
	then
			SILENT=1
	else 
			SILENT=0
	fi
	if [ $1 == "-debug" ]
	then
		DB2_CMD="db2 -tvsf"
		else 
			DB2_CMD="db2 -tsf"
	fi
fi

if [ $# -eq 1 ]
	then
	if [ $1 == "-validate" ]
		then
		   validate
	fi
fi	

if [ $# -eq 2 ]
then
	if [ $2 -eq "-debug" ]
	 then
			DB2_CMD="db2 -tvsf"
	else 
			DB2_CMD="db2 -tsf"
	fi
fi


if [ $SILENT -eq 0 ]
then 
	echo $CRREWECH001
fi	

if [ $SILENT -eq 0 ]
then 
	echo $CRREWPRMPT002
	read DBNAME
fi

if [ -z $DBNAME ]
then
	MESSAGE=$CRREWMSGE002
	EXITCODE=$CRREW4502E
	rcrdone
fi

if [ $SILENT -eq 0 ]
then 
	echo $CRREWPRMPT003
	read DBUSER
fi

if [ -z $DBUSER ]
then
	MESSAGE=$CRREWMSGE003
	EXITCODE=$CRREW4503E
	rcrdone
fi

if [ $SILENT -eq 0 ]
then 
	echo $CRREWPRMPT004
	read DBPASSWD
fi

if [ -z $DBPASSWD ]
then
	MESSAGE=$CRREWMSGE004
	EXITCODE=$CRREW4504E
	rcrdone
fi

if [ $SILENT -eq 0 ]
then 
	echo $CRREWPRMPT005
	read NF_SCHEMA
fi

if [ -z $NF_SCHEMA ]
then
	MESSAGE=$CRREWMSGE005
	EXITCODE=$CRREW4505E
	rcrdone
fi

if [ $SILENT -eq 0 ]
then 
	echo $CRREWPRMPT006
	read STAR_SCHEMA
fi

if [ -z $STAR_SCHEMA ]
then
	MESSAGE=$CRREWMSGE006
	EXITCODE=$CRREW4506E
	rcrdone
fi

if [ $SILENT -eq 0 ]
then 
	echo $CRREWPRMPT007
	read REP_USER
fi

if [ -z $REP_USER ]
then
	MESSAGE=$CRREWMSGE007
	EXITCODE=$CRREW4507E
	rcrdone
fi

if [ $DBUSER == $REP_USER ]
then
	EXITCODE=$CRREW4595E
	MESSAGE=$CRREWMSGE095
	rcrdone
fi

if [ $SILENT -eq 0 ]
then 
	echo $CRREWPRMPT008
	read DATA_HOME
fi

if [ -z $DATA_HOME ]
then
	MESSAGE=$CRREWMSGE008
	EXITCODE=$CRREW4508E
	rcrdone
fi


DATA_HOME=$DATA_HOME/$DBNAME

CONNSTR="db2 CONNECT TO $DBNAME USER $DBUSER USING $DBPASSWD"

if [ $SILENT -eq 1 ]
then 
	$CONNSTR
	db2 "SELECT COUNT(*) FROM CONFIG.ETL_INFO"
	if [ $? -eq 0 ]
	then
		rcrdone
	fi
fi	

CD=`pwd`

if [ ! -d $CD/work_spc ]
then
	mkdir $CD/work_spc
else
	rm -fr $CD/work_spc
	mkdir $CD/work_spc
fi	
if [ $? -ne 0 ]
then
	MESSAGE=$CRREWMSGE076
	EXITCODE=$CRREW4576E
	rcrdone
fi
if [ $? -ne 0 ]
then
	MESSAGE=$CRREWMSGE076
	EXITCODE=$CRREW4576E
	rcrdone
fi
if [ ! -d $CD/logs ]
then
	mkdir $CD/logs
else
	rm -fr $CD/logs
	mkdir $CD/logs	
fi

echo $DATA_HOME/|sed 's/\//\\\//g'>tmp1.txt


cp -r ./createDB $CD/work_spc
if [ $? -ne 0 ]
then
	MESSAGE=$CRREWMSGE024
	EXITCODE=$CRREW4524E
	rcrdone
fi

cat ./createDB/createdb.sql|sed -e "s/\$DBNAME/`echo $DBNAME`/g" > $CD/work_spc/createDB/createdb.sql
cat ./createDB/tbspace.sql|sed -e "s/\$BASEDIR/`cat tmp1.txt`/g" > $CD/work_spc/createDB/tbspace.sql
rm -f tmp1.txt
cat ./scripts/star_grants.sql|sed -e "s/\$STAR_SCHEMA/`echo $STAR_SCHEMA`/g"|sed -e "s/\$REP_USER/`echo $REP_USER`/g"> $CD/work_spc/star_grants.sql
cat ./scripts/dtPopulate.sql|sed -e "s/\$STAR_SCHEMA/`echo $STAR_SCHEMA`/g" > $CD/work_spc/dtPopulate.sql
cat ./scripts/sampledw_obj.sql|sed -e "s/\$STAR_SCHEMA/`echo $STAR_SCHEMA`/g" |sed -e "s/\$NF_SCHEMA/`echo $NF_SCHEMA`/g" > $CD/work_spc/sampledw_obj.sql
cat ./ddl/createSTARViews.ddl|sed -e "s/\$STAR_SCHEMA/`echo $STAR_SCHEMA`/g" |sed -e "s/\$NF_SCHEMA/`echo $NF_SCHEMA`/g" > $CD/work_spc/createSTARViews.ddl
cat ./db2move.lst_original|sed -e "s/\$STAR_SCHEMA/`echo $STAR_SCHEMA`/g" |sed -e "s/\$NF_SCHEMA/`echo $NF_SCHEMA`/g" >move/db2move.lst

$DB2_CMD $CD/work_spc/createDB/createdb.sql >$CD/logs/createdb.log
grep -e "SQLSTATE" $CD/logs/createdb.log >/dev/null

if [ $? -eq 0 ]
then
	MESSAGE=$CRREWMSGE013  
	EXITCODE=$CRREW4513E
	echo $CRREWECH003
	rcrdone
fi
chmod +x ./work_spc/createDB/db2_set.sh
./work_spc/createDB/db2_set.sh
db2set>./logs/db2_set.log
chmod +x ./work_spc/createDB/db_cfg.sh
./work_spc/createDB/db_cfg.sh $DBNAME>./logs/db_cfg.log
chmod +x ./work_spc/createDB/dbm_cfg.sh
./work_spc/createDB/dbm_cfg.sh>./logs/dbm_cfg.log

$CONNSTR

$DB2_CMD ./work_spc/createDB/bufferpool.sql> ./logs/bufferpool.log
grep -e "SQLSTATE" $CD/logs/bufferpool.log>/dev/null

#if [ $? -eq 0 ]
#then
#	MESSAGE=$CRREWMSGE014 
#	EXITCODE=$CRREW4514E
#	echo $CRREWECH004
#	rcrdone
#fi

db2 force applications all
db2stop force
db2start


$CONNSTR

$DB2_CMD ./work_spc/createDB/tbspace.sql> ./logs/tbspace.log
grep -e " SQLSTATE" $CD/logs/tbspace.log>/dev/null
if [ $? -eq 0 ]
then
	MESSAGE=$CRREWMSGE015
	EXITCODE=$CRREW4515E
	echo $CRREWECH005
	rcrdone
fi

cd move
$CONNSTR
$DB2_CMD db2move.lst >IMPORT.out
cd ../

grep -e " SQLSTATE" $CD/move/IMPORT.out>/dev/null
if [ $? -eq 0 ]
then
	MESSAGE=$CRREWMSGE027 
	EXITCODE=$CRREW4527E
	echo $CRREWECH016
	rcrdone
fi

$CONNSTR
$DB2_CMD ./work_spc/sampledw_obj.sql> ./logs/sampledw_obj.log
grep -e " SQLSTATE" $CD/logs/sampledw_obj.log>/dev/null
if [ $? -eq 0 ]
then
	MESSAGE=$CRREWMSGE026  
	EXITCODE=$CRREW4526E
	echo $CRREWECH015
rcrdone
fi

$CONNSTR
$DB2_CMD ./work_spc/createSTARViews.ddl> ./logs/createSTARViews.log
grep -e " SQLSTATE" $CD/logs/createSTARViews.log>/dev/null
if [ $? -eq 0 ]
then
	MESSAGE=$CRREWMSGE019
	EXITCODE=$CRREW4519E
	echo $CRREWECH009
	rcrdone
fi

$CONNSTR
$DB2_CMD ./work_spc/star_grants.sql> ./logs/star_grants.log
grep -e " SQLSTATE" $CD/logs/star_grants.log>/dev/null
if [ $? -eq 0 ]
then
	MESSAGE=$CRREWMSGE023
	EXITCODE=$CRREW4523E
	echo $CRREWECH013
	rcrdone
rcrdone
fi

$CONNSTR
db2 "DROP PROCEDURE $STAR_SCHEMA.POPULATE_D_DATE">logs/drop_proc.log
db2 "DROP PROCEDURE $STAR_SCHEMA.RECALCULATE_D_DATE">>logs/drop_proc.log
db2 "DROP FUNCTION $STAR_SCHEMA.SELECT_ETL_DATE">>logs/drop_proc.log

$CONNSTR
db2 -td@ -vf ./work_spc/dtPopulate.sql> ./logs/dtPopulate.log



rcrdone


